"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Federated = void 0;

var _dedent = _interopRequireDefault(require("dedent"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Namespace for utilities for Module Federation.
 */
let Federated;
exports.Federated = Federated;

(function (_Federated) {
  function createRemote(remoteName) {
    return (0, _dedent.default)`promise new Promise((resolve, reject) => {
      function resolveRemote() {
        resolve({
          get: (request) => {
            return self.${remoteName}.get(request);
          },
          init: (arg) => {
            if (!self.${remoteName}.__isInitialized) {
              try {
                self.${remoteName}.__isInitialized = true;
                return self.${remoteName}.init(arg);
              } catch (e) {
                console.log('[Repack/Federated] Remote container ${remoteName} already initialized.');
              }
            }
          }
        });
      }

      if (self.${remoteName}) {
        return resolveRemote();
      }

      var scriptManager = __webpack_require__.repack.shared.scriptManager;
      scriptManager
        .loadScript('${remoteName}', undefined, __webpack_require__)
        .then(function() {
          resolveRemote();
        })
        .catch(function(reason) {
          reject(reason);
        });
    })`;
  }

  _Federated.createRemote = createRemote;
})(Federated || (exports.Federated = Federated = {}));
//# sourceMappingURL=federated.js.map